## Copyright 2014 Oliver Heimlich
##
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 3 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, see <http://www.gnu.org/licenses/>.

## usage: decimalcompare (X, Y)
##
## Compare two decimal floating point numbers.
##
## See also:
##  str2decimal, double2decimal
##
## Result:
##  negative number, if X < Y,
##  zero, if X == Y,
##  positive number, if X > Y

## Author: Oliver Heimlich
## Keywords: decimal comparison
## Created: 2014-09-29

function result = decimalcompare (x, y)

## Different signs
if (x.s ~= y.s)
    result = y.s - x.s;
    return
endif

## Different exponents
if (x.e ~= y.e)
    result = x.e - y.e;
    if (x.s)
        result .*= -1;
    endif
    return
endif

## Compare common mantissa places
for i = 1 : min (length (x.m), length (y.m))
    if (x.m(i) ~= y.m(i))
        result = x.m(i) - y.m(i);
        if (x.s)
            result .*= -1;
        endif
        return
    endif
endfor

## Compare mantissa length. There is no need to inspect the digits, because the
## mantissa is normalized (no trailing zeroes).
result = length (x.m) - length (y.m);
if (x.s)
    result .*= -1;
endif

endfunction